woodmiceTrees: Bootstrap trees from woodmouse dataset
Description
These trees were created using the neighbour-joining and bootstrapping
example from the ape documentation.
Format
A multiPhylo object containing 201 trees, each with 15 tipsSource
A set of 15 sequences of the mitochondrial gene cytochrome b of the
woodmouse (Apodemus sylvaticus) which is a subset of the data analysed by
Michaux et al. (2003). The full data set is available through GenBank
(accession numbers AJ511877 to AJ511987)References
Michaux, J. R., Magnanou, E., Paradis, E., Nieberding, C. and
Libois, R. (2003) Mitochondrial phylogeography of the Woodmouse (Apodemus
sylvaticus) in the Western Palearctic region. Molecular Ecology, 12,
685-697